Home
====

Envanter is yet another environment parser for Python.

View envanter on:
    * `Github <https://github.com/realsuayip>`_
    * `PyPI <https://pypi.org/project/envanter/>`_

.. toctree::
   :maxdepth: 3
   :numbered:

   self
   install
   usage
   api-reference
